pub fn get( key: <PassFatPointerAndRead<&[u8]> as RIType>::Inner, ) -> <AllocateAndReturnByCodec<Option<Bytes>> as RIType>::Inner
Returns the data for key in the storage or None if the key can not be found.
key
None